Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1930)

Unified Diff: third_party/WebKit/Source/devtools/front_end/services/ServiceManager.js

Issue 2720413006: DevTools: debug remote modules loaded by ServiceManager (Closed)
Patch Set: fixup Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/devtools/front_end/services/ServiceManager.js
diff --git a/third_party/WebKit/Source/devtools/front_end/services/ServiceManager.js b/third_party/WebKit/Source/devtools/front_end/services/ServiceManager.js
index 0d08aeda73549fd6d7344c8754ca05bb651cda62..786dac282b95fa44a282304cbbeef57433be5d67 100644
--- a/third_party/WebKit/Source/devtools/front_end/services/ServiceManager.js
+++ b/third_party/WebKit/Source/devtools/front_end/services/ServiceManager.js
@@ -31,10 +31,13 @@ Services.ServiceManager = class {
createAppService(appName, serviceName, isSharedWorker) {
var url = appName + '.js';
var remoteBase = Runtime.queryParam('remoteBase');
+ var debugFrontend = Runtime.queryParam('debugFrontend');
// Do not pass additional query parameters to shared worker to avoid URLMismatchError
// in case another instance of DevTools with different remoteBase creates same shared worker.
if (remoteBase && !isSharedWorker)
url += '?remoteBase=' + remoteBase;
+ if (debugFrontend && !isSharedWorker)
+ url += '?debugFrontend=' + debugFrontend;
var worker = isSharedWorker ? new SharedWorker(url, appName) : new Worker(url);
var connection = new Services.ServiceManager.Connection(new Services.ServiceManager.WorkerServicePort(worker));
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -31,10 +31,13 @@ Services.ServiceManager = class {
// Do not pass additional query parameters to shared worker to avoid URLMismatchError
- // in case another instance of DevTools with different remoteBase creates same shared worker.
+ // in case another instance of DevTools with different query parameters creates same shared worker.
if (remoteBase && !isSharedWorker)
url += '?remoteBase=' + remoteBase;

Powered by Google App Engine
This is Rietveld 408576698